@@ -75,7 +75,6 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
         extra_params['cloud_provider_enabled'] = cloud_provider_enabled
 
         label_list = ['coredns_tag',
-                      'hyperkube_prefix',
                       'kube_tag', 'container_infra_prefix',
                       'availability_zone',
                       'cgroup_driver',
@@ -99,6 +98,13 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
                       'metrics_server_enabled',
                       'metrics_server_chart_tag',
                       'monitoring_enabled',
+                      'monitoring_retention_days',
+                      'monitoring_retention_size',
+                      'monitoring_interval_seconds',
+                      'monitoring_storage_class_name',
+                      'monitoring_ingress_enabled',
+                      'cluster_basic_auth_secret',
+                      'cluster_root_domain_name',
                       'prometheus_operator_chart_tag',
                       'prometheus_adapter_enabled',
                       'prometheus_adapter_chart_tag',
